@@ -1,14 +1,13 @@
 from __future__ import absolute_import, division, print_function
 
 from stripe import util
-from stripe.api_resources.customer import Customer
 from stripe.api_resources.abstract import DeletableAPIResource
 from stripe.api_resources.abstract import UpdateableAPIResource
-
+from stripe.api_resources.customer import Customer
 from stripe.six.moves.urllib.parse import quote_plus
 
 
-class AlipayAccount(UpdateableAPIResource, DeletableAPIResource):
+class AlipayAccount(DeletableAPIResource, UpdateableAPIResource):
     OBJECT_NAME = "alipay_account"
 
     @classmethod
@@ -28,7 +27,7 @@ class AlipayAccount(UpdateableAPIResource, DeletableAPIResource):
     @classmethod
     def modify(cls, customer, id, **params):
         url = cls._build_instance_url(customer, id)
-        return cls._modify(url, **params)
+        return cls._static_request("post", url, **params)
 
     @classmethod
     def retrieve(
