@@ -4,4 +4,4 @@ from stripe.stripe_object import StripeObject
 
 
 class BitcoinTransaction(StripeObject):
-    OBJECT_NAME = 'bitcoin_transaction'
+    OBJECT_NAME = "bitcoin_transaction"
